@@ -14,31 +14,29 @@ print(f"\n**MONETDB**: We are assuming you are building against MonetDB branch {
 print("**MONETDB**: If this is incorrect, set the MONETDB_BRANCH environment variable during monetdbe-python build\n")
 
 branch_file = str(Path(__file__).parent / 'branch.py')
+newer_then_jul2021 = monetdb_branch.lower() not in ("oct2020", "jul2021")
 
 with open(branch_file, 'w') as f:
     f.write("# this file is created by the cffi interface builder and contains the monetdb branch env variable.\n\n")
     f.write(f"monetdb_branch = '{monetdb_branch}'\n")
+    f.write(f"newer_then_jul2021 = {newer_then_jul2021}\n")
 
 
-default = monetdb_branch.lower() in ("default", "jul2021")
 win32 = platform == 'win32'
 
-
-source = """
-#include "monetdb/monetdbe.h"
-"""
-
+with open(Path(__file__).resolve().parent / "native_utilities.c") as f:
+    source = f.read()
 
 # the ffibuilder object needs to exist and be configured in the module namespace so setup.py can reach it
 ffibuilder = FFI()
-ffibuilder.set_source("monetdbe._lowlevel", source, libraries=['monetdbe'])
-embed_path = str(Path(__file__).parent / 'embed.h.j2')
+ffibuilder.set_source("monetdbe._lowlevel", source=source, libraries=['monetdbe'])
+embed_path = str(Path(__file__).resolve().parent / 'embed.h.j2')
 
 
 with open(embed_path, 'r') as f:
     content = f.read()
     template = Template(content)
-    cdef = template.render(win32=win32, default=default)
+    cdef = template.render(win32=win32, newer_then_jul2021=newer_then_jul2021)
     ffibuilder.cdef(cdef)
 
 
