@@ -6,7 +6,8 @@ import pandas as pd
 from monetdbe.connection import Connection, Description
 from monetdbe.exceptions import ProgrammingError, InterfaceError
 from monetdbe.formatting import format_query, strip_split_and_clean, parameters_type
-from monetdbe.monetize import monet_identifier_escape, convert
+from monetdbe.monetize import monet_identifier_escape
+from monetdbe.types import supported_numpy_types
 
 if TYPE_CHECKING:
     from monetdbe.row import Row
@@ -37,6 +38,12 @@ class Cursor:
 
         self._fetch_generator: Optional[Iterator['Row']] = None
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, exc_type, exc_value, traceback):
+        self.close()
+
     def __del__(self):
         self.close()
 
@@ -120,10 +127,16 @@ class Cursor:
     def _execute_monetdbe(self, operation: str, parameters: parameters_type = None):
         from monetdbe._cffi.internal import bind, execute
         self._check_connection()
-        statement = self.connection.prepare(operation)
+        prepare_result = self.connection.prepare(operation)
+        statement = prepare_result[0]
+
+        self.connection.type_info = None
+        if len(prepare_result) == 2:
+            self.connection.type_info = prepare_result[1]
+
         if parameters:
             for index, parameter in enumerate(parameters):
-                bind(statement, parameter, index)
+                bind(statement, parameter, index, self.connection.type_info)
         self.connection.result, self.rowcount = execute(statement, make_result=True)
         self.connection.cleanup_statement(statement)
         self.connection.total_changes += self.rowcount
@@ -273,7 +286,7 @@ class Cursor:
         query = f"insert into {schema}.{table} ({columns}) values ({qmarks})"
         return self.executemany(query, rows_zipped)
 
-    def insert(self, table: str, values: Union[pd.DataFrame, Dict[str, np.ndarray]], schema: str = 'sys'):
+    def insert(self, table: str, values: Union[pd.DataFrame, Mapping[str, np.ndarray]], schema: str = 'sys'):
         """
         Inserts a set of values into the specified table.
 
@@ -291,7 +304,7 @@ class Cursor:
             if not isinstance(value, (np.ma.core.MaskedArray, np.ndarray)):  # type: ignore
                 prepared[key] = np.array(value)
 
-        if sum(i.dtype.kind not in 'if' for i in prepared.values()):  # type: ignore
+        if sum(i.dtype.kind not in supported_numpy_types for i in prepared.values()):  # type: ignore
             warn(
                 "One of the columns you are inserting is not of type int or float which fast append doesn't support. Falling back to regular insert.")
             return self._insert_slow(table, prepared, schema)
