@@ -7,14 +7,14 @@ import monetdbe
 @pytest.fixture(scope="function")
 def monetdbe_empty_cursor(request, tmp_path):
     test_dbfarm = tmp_path.resolve().as_posix()
+    connection = monetdbe.connect(test_dbfarm)
 
     def finalizer():
         if tmp_path.is_dir():
-            monetdbe.connect(tmp_path).close()
+            connection.close()
             rmtree(test_dbfarm, ignore_errors=True)
 
     request.addfinalizer(finalizer)
-    connection = monetdbe.make_connection(test_dbfarm)
     cursor = connection.cursor()
     return cursor
 
@@ -23,14 +23,15 @@ def monetdbe_empty_cursor(request, tmp_path):
 def monetdbe_cursor(request, tmp_path):
     test_dbfarm = tmp_path.resolve().as_posix()
 
+    connection = monetdbe.connect(test_dbfarm)
+
     def finalizer():
         if tmp_path.is_dir():
-            monetdbe.connect(tmp_path).close()
+            connection.close()
             rmtree(test_dbfarm, ignore_errors=True)
 
     request.addfinalizer(finalizer)
 
-    connection = monetdbe.make_connection(test_dbfarm)
     cursor = connection.cursor()
     cursor.create('integers', {'i': numpy.arange(10)})
     cursor.execute('INSERT INTO integers VALUES(NULL)')
@@ -38,28 +39,36 @@ def monetdbe_cursor(request, tmp_path):
 
 
 @pytest.fixture(scope="function")
-def monetdbe_cursor_autocommit(request, tmp_path):
+def monetdbe_cursor_autocommit(tmp_path):
     test_dbfarm = tmp_path.resolve().as_posix()
-
-    def finalizer():
-        if tmp_path.is_dir():
-            monetdbe.connect(tmp_path).close()
-            rmtree(test_dbfarm, ignore_errors=True)
-
-    request.addfinalizer(finalizer)
     connection = monetdbe.connect(test_dbfarm)
+
     connection.set_autocommit(True)
     cursor = connection.cursor()
-    return cursor, connection, test_dbfarm
+
+    class Context:
+        def __init__(self, cursor, connection, dbfarm):
+            self.cursor = cursor
+            self.connection = connection
+            self.dbfarm = dbfarm
+
+    context = Context(cursor, connection, test_dbfarm)
+
+    yield context
+
+    if tmp_path.is_dir():
+        context.connection.close()
+        rmtree(context.dbfarm, ignore_errors=True)
 
 
 @pytest.fixture(scope="function")
 def initialize_monetdbe(request, tmp_path):
     test_dbfarm = tmp_path.resolve().as_posix()
+    connection = monetdbe.connect(test_dbfarm)
 
     def finalizer():
         if tmp_path.is_dir():
-            monetdbe.connect(tmp_path).close()
+            connection.close()
             rmtree(test_dbfarm, ignore_errors=True)
 
     request.addfinalizer(finalizer)
